Learn R Programming

powerbrmsINLA (version 1.1.1)

.should_stop_binom: Wilson Confidence Interval Early Stopping Rule Determines whether to stop early based on Wilson binomial confidence interval.

Description

Wilson Confidence Interval Early Stopping Rule Determines whether to stop early based on Wilson binomial confidence interval.

Usage

.should_stop_binom(hits, trials, target, margin = 0.02, conf = 0.95)

Value

List with stop (logical) and ci (numeric vector)

Arguments

hits

Number of successes observed

trials

Total number of trials

target

Target proportion

margin

Margin around target for stopping

conf

Confidence level for Wilson CI