Learn R Programming

powerbrmsINLA (version 1.1.1)

.to_inla_family: Map a brms Family to an INLA Family (Modern, Robust)

Description

Map a brms Family to an INLA Family (Modern, Robust)

Convert brms Family to INLA Family Maps brms family specifications to corresponding INLA family names.

Usage

.to_inla_family(family)

.to_inla_family(family)

Value

List with $inla and $brms family names.

List with brms and inla elements containing the family names.

Arguments

family

A brms family object or character string.