| .should_stop_binom | R Documentation |
Wilson Confidence Interval Early Stopping Rule Determines whether to stop early based on Wilson binomial confidence interval.
.should_stop_binom(hits, trials, target, margin = 0.02, conf = 0.95)
hits |
Number of successes observed |
trials |
Total number of trials |
target |
Target proportion |
margin |
Margin around target for stopping |
conf |
Confidence level for Wilson CI |
List with stop (logical) and ci (numeric vector)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.