plot_sequential_monitor: Plot a sequential analysis trajectory with stopping...

View source: R/sequential-analysis.R

plot_sequential_monitorR Documentation

Plot a sequential analysis trajectory with stopping boundaries

Description

Visualises a sequential_analysis() monitor: either the monitored posterior probability across looks with the prespecified success and futility boundaries, or the effect estimate with its credible interval across looks.

Usage

plot_sequential_monitor(
  monitor,
  type = c("probability", "estimate"),
  title = NULL,
  subtitle = NULL
)

Arguments

monitor

A "powerbrmsINLA_seq_monitor" object.

type

"probability" (default) or "estimate".

title, subtitle

Optional plot annotations.

Value

A ggplot object.


powerbrmsINLA documentation built on July 2, 2026, 5:07 p.m.