Wilson Confidence Interval Early Stopping Rule Determines whether to stop early based on Wilson binomial confidence interval.
.should_stop_binom(hits, trials, target, margin = 0.02, conf = 0.95)List with stop (logical) and ci (numeric vector)
Number of successes observed
Total number of trials
Target proportion
Margin around target for stopping
Confidence level for Wilson CI