powered by
Map a brms Family to an INLA Family (Modern, Robust)
Convert brms Family to INLA Family Maps brms family specifications to corresponding INLA family names.
.to_inla_family(family).to_inla_family(family)
.to_inla_family(family)
List with $inla and $brms family names.
List with brms and inla elements containing the family names.
A brms family object or character string.