| plot_bf_assurance_curve_smooth | R Documentation |
Plots the conditional power — the proportion of simulations in which BF10 meets or exceeds a threshold at each fixed effect size — grouped by sample size and any effect grid variables.
plot_bf_assurance_curve_smooth(x, cutoff = 10, effect_filter = NULL)
x |
Engine result (list with $results) or a data.frame with at least
columns |
cutoff |
Numeric Bayes factor threshold for a "hit" (default 10). |
effect_filter |
Optional named list to filter effects,
e.g. |
A ggplot object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.