View source: R/plotting-power.R
| plot_power_heatmap | R Documentation |
Displays the conditional Bayesian power — the probability of meeting the decision criterion at each fixed effect size — as a colour-filled heatmap.
plot_power_heatmap(
power_results,
power_metric = c("direction", "threshold", "rope"),
x_effect = NULL,
y_effect = "n",
facet_by = NULL,
title = NULL,
subtitle = NULL
)
power_results |
Output from a |
power_metric |
Which metric to plot: "direction", "threshold", or "rope". |
x_effect |
Name of effect grid column for x-axis (default = first effect). |
y_effect |
Name of effect grid column for y-axis (default = "n"). |
facet_by |
Optional effect grid column(s) to facet by. |
title, subtitle |
Optional plot labels. |
Heatmap of conditional Bayesian power for a chosen metric across two selected effect grid variables and sample sizes.
These plots display conditional Bayesian power — the probability of
meeting the decision criterion at a fixed effect size. For unconditional
assurance (averaged over a design prior on effect size), see
plot_assurance_curve().
A ggplot object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.