View source: R/sequential-analysis.R
| plot_sequential_monitor | R Documentation |
Visualises a sequential_analysis() monitor: either the monitored
posterior probability across looks with the prespecified success and
futility boundaries, or the effect estimate with its credible interval
across looks.
plot_sequential_monitor(
monitor,
type = c("probability", "estimate"),
title = NULL,
subtitle = NULL
)
monitor |
A |
type |
|
title, subtitle |
Optional plot annotations. |
A ggplot object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.